brain_dev_business
A new Flutter project interface for Google ads, Firebase Message Service, Local notification.
Getting Started
This project is a starting point for a Flutter plug-in package, a specialized package that includes platform-specific implementation code for Android and/or iOS.
For help getting started with Flutter development, view the online documentation, which offers tutorials, samples, guidance on mobile development, and a full API reference.
Libraries
- brain_dev_business
- brain_dev_business_method_channel
- brain_dev_business_platform_interface
- brain_dev_business_web
- config/dependencies_tools
- config/routes/route_helper_business_auth
- config/routes/route_helper_business_bible
- config/routes/route_name
- controllers/business_controller
- entities/dao/properties/users_property
- models/notification/day_verses_model
- models/notification/notification_model
- models/notification/payload_model
- models/notification/received_notification
- models/notification/response/channel_model
- models/notification/response/message_notification_model
- models/notification/response/notification_model
- models/users_model
- repository/user_repository
- services/sender_firebase_message_service
- services/sender_google_ads_service
- services/sender_notification_local_service