UsersProperty class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- activeYN → Property
-
final
- askPassword → Property
-
final
- authKey → Property
-
final
- baseDeviceInfo → Property
-
final
- biographie → Property
-
final
- connecterYN → Property
-
final
- connectFrom → Property
-
final
- dateCreated → Property
-
final
- dateCreatedDisplay → Property
-
final
- dateModif → Property
-
final
- dateModifDisplay → Property
-
final
- email → Property
-
final
- facebookUrl → Property
-
final
- fcmNewToken → Property
-
final
- fcmOldToken → Property
-
final
- followerCount → Property
-
final
- followerId → Property
-
final
- followingCount → Property
-
final
- goutDuChefId → Property
-
final
- groupeRole → Property
-
final
- groupeUserId → Property
-
final
- id → Property
-
final
- idAppFireBase → Property
-
final
- idFirebaseToken → Property
-
final
- idUserAPI → Property
-
final
- instragramUrl → Property
-
final
- isAdminPrivilege → Property
-
final
- isAppProvider → Property
-
final
- isDelete → Property
-
final
- isEmailVerified → Property
-
final
- isFollowing → Property
-
final
- isForcedOut → Property
-
final
- isPhotoPathLocalDelete → Property
-
final
- isValidateAccount → Property
-
final
- jWTToken → Property
-
final
- lastLogin → Property
-
final
- lastLoginDisplay → Property
-
final
- localisation → Property
-
final
- motDePasse → Property
-
final
- nomComplet → Property
-
final
- packageName → Property
-
final
- permissions → Property
-
final
- photoBase64 → Property
-
final
- photoPath → Property
-
final
- photoPathLocal → Property
-
final
- photoPathUrl → Property
-
final
- pinterestUrl → Property
-
final
- projectId → Property
-
final
- raison → Property
-
final
- recipeCount → Property
-
final
- role → Property
-
final
- roleStr → Property
-
final
- userCreated → Property
-
final
- userName → Property
-
final
- youtubeUrl → Property
-
final