DayVersesModel class

Constructors

DayVersesModel({String bookOsis = '', int chapter = 0, int verse = 0})
DayVersesModel.fromJson(Map<String, dynamic> map)
factory

Properties

bookOsis String
getter/setter pair
chapter int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jsonEncodeString String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verse int
getter/setter pair

Methods

convertToJson() Map<String, dynamic>
fromJson(String str) DayVersesModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited