MessageNotification class

Constructors

MessageNotification({int id = 0, String title = '', String body = '', String image = '', int status = 0, String createdAt = '', String receiver = ''})
MessageNotification.fromJson(Map<String, dynamic> jsonData)
MessageNotification.parseNotification(dynamic notification)

Properties

body String
getter/setter pair
channel ChannelModel
getter/setter pair
createdAt String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
image String
getter/setter pair
payload String?
getter/setter pair
receiver String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
getter/setter pair
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited