PayLoadModel class

Constructors

PayLoadModel({int notificationId = 0, String codePage = '', String pageUrl = '', String titre = '', String description = '', String imageBg = ''})
PayLoadModel.fromJson(Map<String, dynamic> map)
factory

Properties

codePage String
getter/setter pair
dayVerses DayVersesModel?
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageBg String
getter/setter pair
jsonEncodeString String
no setter
notificationId int
getter/setter pair
pageUrl String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titre String
getter/setter pair

Methods

fromJson(String str) PayLoadModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited