ChannelModel2 class

Constructors

ChannelModel2({String id = Constant.channel_notification_song_share, String name = Constant.channel_notification_song_share, String description = Constant.channel_notification_song_share})
ChannelModel2.fromJson(Map<String, dynamic> json)

Properties

description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
jsonEncodeString String
no setter
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited