MessageNotificationModel class

Constructors

MessageNotificationModel({int id = 0, String title = '', String body = '', String userId = '', String imagePath = ''})
MessageNotificationModel.fromJsonData(Map<String, dynamic> jsonData)
MessageNotificationModel.parseNotification(dynamic notification)

Properties

body String
getter/setter pair
channel ChannelModel
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
imagePath String
getter/setter pair
jsonEncodeString String
no setter
payload PayLoadModel
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair
userId String
getter/setter pair

Methods

convertToJson() Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited