UserRepository class

Constructors

UserRepository({required ApiClient apiClient, required SharedPreferences sharedPreferences})

Properties

apiClient ↔ ApiClient
getter/setter pair
dataFrom String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferences ↔ SharedPreferences
getter/setter pair
tableName String
getter/setter pair
tentative int
getter/setter pair
userConnected UserModel
getter/setter pair

Methods

checkIfUserIsFollowing({required String userId, required String followerId}) Future
checkPermission({List<String>? permissions, String? permission, String logicalOp = 'AND'}) bool
deleteAccountOnTheCloud({required String raison}) Future<MessageModel>
deleteAllDataOnTheCloud({required String raison}) Future<MessageModel>
getProfileInfo({required String userId, required bool isPublic}) Future
getSigleName({required String nomComplet}) String
getUserConnected() → dynamic
getUserUI({dynamic currentUser}) Future
loginProviderModel({required UserModel user, required String urlApi}) Future<UserModel?>
loginRegisterProvider({required UserModel user}) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserConnected({required UserModel user}) → dynamic
toString() String
A string representation of this object.
inherited
tryTokenAutoAuthenticate() Future
updatePhotoProfile({required UserModel user}) Future
updateProfile({required UserModel user}) Future

Operators

operator ==(Object other) bool
The equality operator.
inherited