SenderNotificationLocalService class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateNotification({required String time, required PayLoadModel payLoad, ChannelModel? channel}) Future<void>
cancelAllNotification() Future<void>
cancelNotification({required int id}) Future<void>
myBackgroundMessageHandler(dynamic message) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
repeatNotification() Future<void>
showBigPictureNotificationHiddenLargeIcon({required MessageNotificationModel mNotif}) Future<void>
showBigTextNotification({required MessageNotificationModel mNotif}) Future<void>
showNotification({required dynamic message}) Future<void>
showNotificationDemo() Future<void>
showTextNotification({required MessageNotificationModel mNotif}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited